@@ -11,15 +11,14 @@ import numpy as np
 from skgenome import tabio, GenomicArray as GA
 
 
-def do_access(fa_fname, exclude_fnames=(), min_gap_size=5000,
-              skip_noncanonical=True):
+def do_access(fa_fname, exclude_fnames=(), min_gap_size=5000, skip_noncanonical=True):
     """List the locations of accessible sequence regions in a FASTA file."""
     fa_regions = get_regions(fa_fname)
     if skip_noncanonical:
         fa_regions = drop_noncanonical_contigs(fa_regions)
     access_regions = GA.from_rows(fa_regions)
     for ex_fname in exclude_fnames:
-        excluded = tabio.read(ex_fname, 'bed3')
+        excluded = tabio.read(ex_fname, "bed3")
         access_regions = access_regions.subtract(excluded)
     return GA.from_rows(join_regions(access_regions, min_gap_size))
 
@@ -31,9 +30,10 @@ def drop_noncanonical_contigs(region_tups):
 
     Yield the same, but dropping noncanonical chrom.
     """
+    # Avoid a circular import
     from .antitarget import is_canonical_contig_name
-    return (tup for tup in region_tups
-            if is_canonical_contig_name(tup[0]))
+
+    return (tup for tup in region_tups if is_canonical_contig_name(tup[0]))
 
 
 def get_regions(fasta_fname):
@@ -41,7 +41,7 @@ def get_regions(fasta_fname):
     with open(fasta_fname) as infile:
         chrom = cursor = run_start = None
         for line in infile:
-            if line.startswith('>'):
+            if line.startswith(">"):
                 # Emit the last chromosome's last run, if any
                 if run_start is not None:
                     yield log_this(chrom, run_start, cursor)
@@ -52,16 +52,16 @@ def get_regions(fasta_fname):
                 logging.info("%s: Scanning for accessible regions", chrom)
             else:
                 line = line.rstrip()
-                if 'N' in line:
-                    if all(c == 'N' for c in line):
+                if "N" in line:
+                    if all(c == "N" for c in line):
                         # Shortcut if the line is all N chars
                         if run_start is not None:
                             yield log_this(chrom, run_start, cursor)
                             run_start = None
                     else:
                         # Slow route: line is a mix of N and non-N chars
-                        line_chars = np.array(line, dtype='c')
-                        n_indices = np.where(line_chars == b'N')[0]
+                        line_chars = np.array(line, dtype="c")
+                        n_indices = np.where(line_chars == b"N")[0]
                         # Emit the first block of non-N chars, if any
                         if run_start is not None:
                             yield log_this(chrom, run_start, cursor + n_indices[0])
@@ -91,8 +91,13 @@ def get_regions(fasta_fname):
 
 def log_this(chrom, run_start, run_end):
     """Log a coordinate range, then return it as a tuple."""
-    logging.info("\tAccessible region %s:%d-%d (size %d)",
-                 chrom, run_start, run_end, run_end - run_start)
+    logging.info(
+        "\tAccessible region %s:%d-%d (size %d)",
+        chrom,
+        run_start,
+        run_end,
+        run_end - run_start,
+    )
     return (chrom, run_start, run_end)
 
 
@@ -101,21 +106,31 @@ def join_regions(regions, min_gap_size):
     min_gap_size = min_gap_size or 0
     for chrom, rows in regions.by_chromosome():
         logging.info("%s: Joining over small gaps", chrom)
-        coords = iter(zip(rows['start'], rows['end']))
+        coords = iter(zip(rows["start"], rows["end"]))
         prev_start, prev_end = next(coords)
         for start, end in coords:
             gap = start - prev_end
-            assert gap > 0, ("Impossible gap between %s %d-%d and %d-%d (=%d)"
-                             % (chrom, prev_start, prev_end, start, end, gap))
+            assert gap > 0, (
+                f"Impossible gap between {chrom} {prev_start}-{prev_end} "
+                + f"and {start}-{end} (={gap})"
+            )
             if gap < min_gap_size:
                 # Join with the previous region
-                logging.info("\tJoining %s %d-%d and %d-%d (gap size %d)",
-                             chrom, prev_start, prev_end, start, end, gap)
+                logging.info(
+                    "\tJoining %s %d-%d and %d-%d (gap size %d)",
+                    chrom,
+                    prev_start,
+                    prev_end,
+                    start,
+                    end,
+                    gap,
+                )
                 prev_end = end
             else:
                 # Keep the gap; emit the previous region as-is
-                logging.info("\tKeeping gap %s:%d-%d (size %d)",
-                             chrom, prev_end, start, gap)
+                logging.info(
+                    "\tKeeping gap %s:%d-%d (size %d)", chrom, prev_end, start, gap
+                )
                 yield (chrom, prev_start, prev_end)
                 prev_start, prev_end = start, end
         yield (chrom, prev_start, prev_end)
