@@ -29,7 +29,8 @@ def batch_make_reference(
     normal_bams,
     target_bed,
     antitarget_bed,
-    male_reference,
+    is_haploid_x_reference,
+    diploid_parx_genome,
     fasta,
     annotate,
     short_names,
@@ -154,7 +155,7 @@ def batch_make_reference(
     if len(normal_bams) == 0:
         logging.info("Building a flat reference...")
         ref_arr = reference.do_reference_flat(
-            target_bed, antitarget_bed, fasta, male_reference
+            target_bed, antitarget_bed, fasta, is_haploid_x_reference, diploid_parx_genome
         )
     else:
         logging.info("Building a copy number reference from normal samples...")
@@ -196,7 +197,8 @@ def batch_make_reference(
             target_fnames,
             antitarget_fnames,
             fasta,
-            male_reference,
+            is_haploid_x_reference,
+            diploid_parx_genome,
             None,
             do_gc=True,
             do_edge=(method == "hybrid"),
@@ -223,7 +225,8 @@ def batch_run_sample(
     antitarget_bed,
     ref_fname,
     output_dir,
-    male_reference,
+    is_haploid_x_reference,
+    diploid_parx_genome,
     plot_scatter,
     plot_diagram,
     rscript_path,
@@ -253,6 +256,7 @@ def batch_run_sample(
         raw_tgt,
         raw_anti,
         read_cna(ref_fname),
+        diploid_parx_genome,
         do_gc=True,
         do_edge=(seq_method == "hybrid"),
         do_rmask=True,
@@ -264,6 +268,7 @@ def batch_run_sample(
     segments = segmentation.do_segmentation(
         cnarr,
         segment_method,
+        diploid_parx_genome,
         rscript_path=rscript_path,
         skip_low=skip_low,
         processes=processes,
@@ -289,7 +294,7 @@ def batch_run_sample(
         cnarr, seg_call, location_stats=["p_ttest"], skip_low=skip_low
     )
     # Finally, assign absolute copy number values to each segment
-    seg_alltest.center_all("median")
+    seg_alltest.center_all("median", diploid_parx_genome=diploid_parx_genome)
     seg_final = call.do_call(seg_alltest, method="threshold")
     tabio.write(seg_final, sample_pfx + ".call.cns")
 
@@ -303,11 +308,11 @@ def batch_run_sample(
         logging.info("Wrote %s-scatter.png", sample_pfx)
 
     if plot_diagram:
-        is_xx = cnarr.guess_xx(male_reference)
+        is_xx = cnarr.guess_xx(is_haploid_x_reference, diploid_parx_genome)
         outfname = sample_pfx + "-diagram.pdf"
         diagram.create_diagram(
-            cnarr.shift_xx(male_reference, is_xx),
-            seg_final.shift_xx(male_reference, is_xx),
+            cnarr.shift_xx(is_haploid_x_reference, is_xx, diploid_parx_genome),
+            seg_final.shift_xx(is_haploid_x_reference, is_xx, diploid_parx_genome),
             0.5,
             3,
             outfname,
