@@ -194,7 +194,7 @@ def interval_coverages_pileup(bed_fname, bam_fname, min_mapq, procs=1, fasta=Non
     # User-supplied bins might be zero-width or reversed -- skip those
     spans = table.end - table.start
     ok_idx = spans > 0
-    table = table.assign(depth=0, log2=NULL_LOG2_COVERAGE)
+    table = table.assign(depth=0.0, log2=NULL_LOG2_COVERAGE)
     table.loc[ok_idx, "depth"] = table.loc[ok_idx, "basecount"] / spans[ok_idx]
     ok_idx = table["depth"] > 0
     table.loc[ok_idx, "log2"] = np.log2(table.loc[ok_idx, "depth"])
@@ -216,7 +216,7 @@ def bedcov(bed_fname, bam_fname, min_mapq, fasta=None):
     # Count bases in each region; exclude low-MAPQ reads
     cmd = [bed_fname, bam_fname]
     if min_mapq and min_mapq > 0:
-        cmd.extend(["-Q", bytes(min_mapq)])
+        cmd.extend(["-Q", str(min_mapq)])
     if fasta:
         cmd.extend(["--reference", fasta])
     try:
