@@ -16,3 +16,10 @@ INSERT_SIZE = 250
 IGNORE_GENE_NAMES = ("-", ".", "CGH")
 ANTITARGET_NAME = "Antitarget"
 ANTITARGET_ALIASES = (ANTITARGET_NAME, "Background")
+
+# PAR1/2 start/end definitions
+PSEUDO_AUTSOMAL_REGIONS = {
+    "grch37": {"PAR1X": [60000, 2699520], "PAR2X": [154931043, 155260560], "PAR1Y": [10000, 2649520], "PAR2Y": [59034049, 59363566] },
+    "grch38": {"PAR1X": [10000, 2781479], "PAR2X": [155701382, 156030895], "PAR1Y": [10000, 2781479], "PAR2Y": [56887902, 57217415] },
+}
+SUPPORTED_GENOMES_FOR_PAR_HANDLING = PSEUDO_AUTSOMAL_REGIONS.keys()
\ No newline at end of file
