@@ -20,6 +20,7 @@ SEGMENT_METHODS = ("cbs", "flasso", "haar", "none", "hmm", "hmm-tumor", "hmm-ger
 def do_segmentation(
     cnarr,
     method,
+    diploid_parx_genome=None,
     threshold=None,
     variants=None,
     skip_low=False,
@@ -62,6 +63,7 @@ def do_segmentation(
         cna = _do_segmentation(
             cnarr,
             method,
+            diploid_parx_genome,
             threshold,
             variants,
             skip_low,
@@ -83,6 +85,7 @@ def do_segmentation(
                         (
                             ca,
                             method,
+                            diploid_parx_genome,
                             threshold,
                             variants,
                             skip_low,
@@ -126,6 +129,7 @@ def _ds(args):
 def _do_segmentation(
     cnarr,
     method,
+    diploid_parx_genome,
     threshold,
     variants=None,
     skip_low=False,
@@ -177,7 +181,7 @@ def _do_segmentation(
         segarr = none.segment_none(filtered_cn)
 
     elif method.startswith("hmm"):
-        segarr = hmm.segment_hmm(filtered_cn, method, threshold, variants)
+        segarr = hmm.segment_hmm(filtered_cn, method, diploid_parx_genome, threshold, variants)
 
     elif method in ("cbs", "flasso"):
         # Run R scripts to calculate copy number segments
